import type { HeaderEntry } from './navigation'
import type { MediaEntryTag } from '../content/entryTag'
import type { RouteCollection } from './routing'
import type { SiteThemeList } from './themes'
import type { WarningModal } from './warnings'

/**
 * Defines global values for the site.
 */
export type SiteGlobals = {
  /**
   * Route config
   */
  routes: RouteCollection
  /**
   * Header config
   */
  header: HeaderEntry[]
  /**
   * Identifier for the site (used for prefixing site cache values)
   */
  id: string
  /**
   * Global stylesheets shared across all pages to load for the site;
   * these are additive and not overridden by per-page stylesheet URLs
   */
  stylesheetUrls: string[]
  /**
   * Theme config
   */
  themes: SiteThemeList
  /**
   * Tags used by certain templates
   */
  tags?: string | MediaEntryTag[]
  /**
   * Default modal text shown by certain templates that may feature content warnings;
   * can be overridden per-page, this is used as a fallback when not defined per-page.
   */
  warning: WarningModal
}
