/**
 * Defines a stylesheet the site uses for applying a theme
 */
export type SiteTheme = {
  /**
   * User-friendly name to render in the site theme picker
   */
  displayName?: string
  /**
   * What kind of theme it is for accessibility purposes
   */
  type: SiteThemeType
  /**
   * The stylesheet url for the theme
   */
  url: string
}

/**
 * Defines a list of themes the site uses
 */
export type SiteThemeList = { [id: string]: SiteTheme }

/**
 * Defines what kind of theme a specified theme is
 * for the purposes of determining a default theme
 * based on the system/browser setting of the visitor
 */
export type SiteThemeType = (
  | 'dark'
  | 'light'
  | 'dark_hc'
  | 'light_hc'
)
